#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Financial
Print

# Case Information

21D00001 | STANFORD OAKS 2017 LLC DBA STANFORD OAKS APARTMENTS VS KEYONIA DONALDSON,AND ALL OTHER OCCUPANTS

Case Number
21D00001

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
01/03/2021

Case Type
Magistrate Dispossessory - Non Payment of Rent

Case Status
Closed

# Party

Plaintiff
STANFORD OAKS 2017 LLC DBA STANFORD OAKS APARTMENTS

Address

2035 IDLEWOOD RD
TUCKER GA 30084

Active Attorneys

Lead Attorney
Williams, J Mike

Retained

Defendant
DONALDSON, KEYONIA

Address

2035 IDLEWOOD RD
Y-6
TUCKER GA 30084

Defendant
AND ALL OTHER OCCUPANTS

Address

2035 IDLEWOOD RD
Y-6
TUCKER GA 30084

# Disposition Events

01/22/2021 Judgment

Judgment Type
Dismissed without Prejudice

# Events and Hearings

- 01/03/2021 Dispossessory Warrant

  Comment
  Of the plaintiff

- 01/06/2021 Affidavit of Service

  Comment
  Answer due 1/12/21

- 01/22/2021 Dismissal

  Comment
  VOLUNTARY DISMISSAL

Loading financial, please wait...